@@ -7,10 +7,12 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.94_2';
+$VERSION = '0.94_3';
 
 
-our $VERSION = '0.94_2';
+# The VERSION of the distribution is sourced from this file, because
+# this module also loads the XS extension.
+our $VERSION = '0.94_3';
 use Carp 'croak';
 
 { use XSLoader;
@@ -22,8 +24,9 @@ use Carp 'croak';
 my $in_constant_table;
 BEGIN { $in_constant_table = qr/
    ^_CS_    # confstr
+ | ^DN_     # fcntl
  | ^E(?!CHONL|XIT_) # errno   ECHONL in Termios, EXIT_ in Proc
- | ^WSAE    # errno (windows sockets)
+ | ^F_      # fcntl
  | ^GET_    # rlimit
  | ^O_      # fdio
  | ^_PC_    # pathconf
@@ -36,6 +39,7 @@ BEGIN { $in_constant_table = qr/
  | ^SET_    # rlimit aix
  | ^SIG[^_] # signals
  | ^UL_     # ulimit
+ | ^WSAE    # errno (windows sockets)
  | _OK$     # access
  /x
 };
@@ -139,7 +143,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.94_2';
+$VERSION = '0.94_3';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
